guix_mirror_bot pushed a commit to branch next-master
in repository guix.

commit 09a9b46387e6cd9ee2da2e12e07e062067551875
Author: Nicolas Graves <[email protected]>
AuthorDate: Tue Jan 6 11:46:49 2026 +0100

    gnu: fp16: Switch to pyproject.
    
    * gnu/packages/maths.scm (fp16):
    [arguments]<#:modules, #:imported-modules, #:phases>: Switch to
    pyproject-build-system.
    
    Change-Id: I6ca525ea3f5704b4afce39837c21e704e2a13370
    Signed-off-by: Sharlatan Hellseher <[email protected]>
---
 gnu/packages/maths.scm | 52 +++++++++++++++++++++++++-------------------------
 1 file changed, 26 insertions(+), 26 deletions(-)

diff --git a/gnu/packages/maths.scm b/gnu/packages/maths.scm
index c2e3441bf2..68a7dd3784 100644
--- a/gnu/packages/maths.scm
+++ b/gnu/packages/maths.scm
@@ -10898,32 +10898,32 @@ when an application performs repeated divisions by 
the same divisor.")
                                          "fp16-system-libraries.patch"))))
       (build-system cmake-build-system)
       (arguments
-       `(#:imported-modules ((guix build python-build-system)
-                             ,@%cmake-build-system-modules)
-         #:modules (((guix build python-build-system)
-                     #:select (site-packages))
-                    (guix build cmake-build-system)
-                    (guix build utils))
-         #:phases (modify-phases %standard-phases
-                    (add-after 'install 'move-python-files
-                      (lambda* (#:key inputs outputs #:allow-other-keys)
-                        ;; Python files get installed to $includedir (!).
-                        ;; Move them to the usual Python site directory.
-                        (let* ((out     (assoc-ref outputs "out"))
-                               (include (string-append out "/include"))
-                               (site    (site-packages inputs outputs))
-                               (target  (string-append site "/fp16")))
-                          (mkdir-p target)
-                          (for-each (lambda (file)
-                                      (rename-file file
-                                                   (string-append target "/"
-                                                                  (basename
-                                                                   file))))
-                                    (find-files include "\\.py$"))))))))
-      (native-inputs
-       (list python-wrapper))
-      (inputs
-       (list psimd googletest-1.8 googlebenchmark))
+       (list
+        #:imported-modules
+        (append %cmake-build-system-modules
+                %pyproject-build-system-modules)
+        #:modules
+        `(((guix build pyproject-build-system) #:select (site-packages))
+          (guix build cmake-build-system)
+          (guix build utils))
+        #:phases
+        (with-extensions (list (pyproject-guile-json))
+          #~(modify-phases %standard-phases
+              (add-after 'install 'move-python-files
+                (lambda* (#:key inputs outputs #:allow-other-keys)
+                  ;; Python files get installed to $includedir (!).
+                  ;; Move them to the usual Python site directory.
+                  (let* ((include (string-append #$output "/include"))
+                         (site (site-packages inputs outputs))
+                         (target (string-append site "/fp16")))
+                    (mkdir-p target)
+                    (for-each (lambda (file)
+                                (rename-file file
+                                             (string-append target "/"
+                                                            (basename file))))
+                              (find-files include "\\.py$")))))))))
+      (native-inputs (list python-wrapper))
+      (inputs (list psimd googletest-1.8 googlebenchmark))
       (synopsis "C++ library for half-precision floating point formats")
       (description
        "This header-only C++ library implements conversion to and from

Reply via email to